===============
portal-core
===============

.. image:: https://github.com/kacotam-si/portal-core/actions/workflows/django.yml/badge.svg?branch=master
    :target: https://github.com/kacotam-si/portal-core/actions/workflows/django.yml
    :alt: Django CI

.. image:: https://coveralls.io/repos/github/kacotam-si/portal-core/badge.svg?branch=master
    :target: https://coveralls.io/github/kacotam-si/portal-core?branch=master
    :alt: COVERALLS

.. image:: https://codeclimate.com/github/kacotam-si/portal-core/badges/gpa.svg
   :target: https://codeclimate.com/github/kacotam-si/portal-core
   :alt: Code Climate

.. image:: https://codeclimate.com/github/kacotam-si/portal-core/badges/issue_count.svg
   :target: https://codeclimate.com/github/kacotam-si/portal-core
   :alt: Issue Count

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
   :target: https://raw.githubusercontent.com/kacotam-si/portal-core/master/LICENSE
   :alt: LICENSE MIT


**portal-core** is Portal System Core functions.


Requirement
============

* Python >= 3.6
* Django >= 3.2


Quick start
============

1. Install by pip ::

    # install from github master branch
    pip install -U https://github.com/kacotam-si/portal-core/archive/master.tar.gz


2. Add "portal_core" to INSTALLED_APPS ::

    INSTALLED_APPS = [
        ...
        'portal_core',
        ...
    ]


3. Set Valuse in settings ::

    #

4. Usage ::

    import portal_core

Acknowledgements
=================
